@@ -41,6 +41,7 @@ class HypixelPlayer:
         self.name = data.get("player", {}).get("displayname")
         self.uuid = data.get("player", {}).get("uuid")
         self.rank = Rank(data)
+        self.level = Level(data)
         self.karma = data.get("player", {}).get("karma", 0)
         self.achievement_points = data.get("player", {}).get("achievementPoints", 0)
         self.logins = LoginTimes(data)
@@ -79,4 +80,11 @@ class Rank:
         return self.name
 
     def __bool__(self):
-        return self.name
+        return bool(self.name)
+
+
+class Level:
+    def __init__(self, data):
+        self.exact = utils.get_network_level_exact(data.get("player", {}).get("networkExp"))
+        self.level = utils.get_network_level(data.get("player", {}).get("networkExp"))
+        self.percentage = utils.get_level_percentage(self.exact)
