@@ -36,7 +36,7 @@ rank_colors = {
     None: int("607D8B", 16)
 }
 
-bedwars_prestiges = [
+bedwars_prestiges = (
     "Stone",
     "Iron",
     "Gold",
@@ -68,9 +68,24 @@ bedwars_prestiges = [
     "Earth",
     "Water",
     "Fire"
-]
+)
 
-bedwars_prestige_colors = [
+skywars_prestiges = (
+    "Stone",
+    "Iron",
+    "Gold",
+    "Diamond",
+    "Emerald",
+    "Sapphire",
+    "Ruby",
+    "Crystal",
+    "Opal",
+    "Amethyst",
+    "Rainbow",
+    "Mystic"
+)
+
+bedwars_prestige_colors = (
     int("607D8B", 16),
     int("95A5A6", 16),
     int("FFAC0F", 16),
@@ -92,7 +107,21 @@ bedwars_prestige_colors = [
     int("FF69DC", 16),
     int("2562E9", 16),
     int("AA00AA", 16)  # i don't know the colors past this point yet
-]
+)
+
+skywars_prestige_colors = (
+    int("607D8B", 16),
+    int("95A5A6", 16),
+    int("FFAC0F", 16),
+    int("55FFFF", 16),
+    int("00AA00", 16),
+    int("00AAAA", 16),
+    int("AA0000", 16),
+    int("FF69DC", 16),
+    int("2562E9", 16),
+    int("AA00AA", 16),
+    int("AA00AA", 16),  # last two prestiges use the same color
+)
 
 
 def get_ratio(positive_stat, negative_stat):
@@ -111,6 +140,23 @@ def get_increase(positive_stat, negative_stat, *, amount: int = 0):
     return round(needed)
 
 
+def get_network_level(experience):
+    # formula that i don't understand
+    # thank you @littlemxantivirus
+    return math.trunc(get_network_level_exact(experience))
+
+
+def get_network_level_exact(experience):
+    # formula that i don't understand
+    # thank you @littlemxantivirus
+    return (math.sqrt(experience + 15312.5) - 88.38834764831843) / 35.35533905932738
+
+
+def get_level_percentage(level: float):
+    # i wrote this months ago so idk but it's probably just math tho
+    return round((level - math.trunc(level)) * 100, 2)
+
+
 def get_bedwars_prestige_name(star_index):
     if star_index > len(bedwars_prestiges) - 1:
         star_index = len(bedwars_prestiges) - 1
@@ -123,6 +169,39 @@ def get_bedwars_prestige_color(star_index):
     return bedwars_prestige_colors[star_index]
 
 
+def get_skywars_level(experience):
+    return math.trunc(get_skywars_level_exact(experience))
+
+
+def get_skywars_level_exact(experience):
+    # another formula that I don't understand, thanks to @GamingGeeek and @littlemissantivirus
+    total_xp = [20, 70, 150, 250, 500, 1000, 2000, 3500, 6000, 10000, 15000]
+    level = 0
+    if experience >= 15000:
+        level = (experience - 15000) / 10000 + 12
+    else:
+        c = 0
+        while experience >= 0 and c < len(total_xp):
+            if experience - total_xp[c] >= 0:
+                c += 1
+            else:
+                level = c + 1 + (experience - total_xp[c - 1]) / (total_xp[c] - total_xp[c - 1])
+                break
+    return level
+
+
+def get_skywars_prestige_name(star_index):
+    if star_index > len(skywars_prestiges) - 1:
+        star_index = len(skywars_prestiges) - 1
+    return skywars_prestiges[star_index]
+
+
+def get_skywars_prestige_color(star_index):
+    if star_index > len(skywars_prestige_colors) - 1:
+        star_index = len(skywars_prestige_colors) - 1
+    return skywars_prestige_colors[star_index]
+
+
 def get_rank(rank, prefix_raw, monthly_package_rank, new_package_rank, package_rank):
     real_rank = None
     if prefix_raw:
